==> gbsite-1.0.0.tar.gz: gbsite/htdocs/browse.php <==
<?

/**************************************************
Program name:		meminfo.php  
Author:			Allen mcGrath (amcgrath@greatbridge.com)

Description:		browses through the projects via
			the cat_id
			
Create Date:		10/11/00 

Modified Date(s):	

**************************************************/

$web_page = "browsepage";
include("site_info.php");
$group_group_id = "browse";

$cat_id = (!empty($QUERY_STRING) ? $QUERY_STRING : 0);

# get the name of the category being browsed

$cn_query = "SELECT CAT_NAME, PARENT_ID FROM CATEGORY WHERE CAT_ID = $cat_id";
$cn_result = pg_exec($conn,$cn_query);

if (pg_numrows($cn_result) > 0) {
$curr_cat = pg_fetch_object($cn_result,0);
$parent_id		= $curr_cat->parent_id;
$cat_name 	= $curr_cat->cat_name;
}

# assign the link back variable
if ($parent_id == 0 && !empty($QUERY_STRING)) $back_link = "(All Categories)";
else if ($parent_id > 0 && !empty($QUERY_STRING)) $back_link = "(Back One Level)";


# call the function to build the list of children
$cat_list = getCats($cat_id);


# now get the projects that are in this category or below it
$ps_query = "select distinct a.project_id, b.project_name, b.project_title, " .
	    "b.description from project_category a, project b " .
	    "where a.cat_id in (select c.cat_id from category c " .
	    "where c.type_id = 7 and (c.parent_id = $cat_id or c.cat_id = $cat_id)) " .
	    "and a.project_id = b.project_id " .
	    "and b.approved = 't'";

$ps_result = pg_exec($conn,$ps_query);

$ps = 0;
	while ($row = @pg_fetch_array($ps_result,$ps++)) {
		$project_list[] = array( "project_id" => $row["project_id"],
	                       "project_title" => $row["project_title"],
				 "project_name" => $row["project_name"],
				 "description" => $row["description"]);
	}

include($page_template);

?>

==> gbsite-2.0.0.tar.gz: gbsite/htdocs/browse.php <==
<?

/**************************************************
Program name:		meminfo.php  
Author:			Allen mcGrath (amcgrath@greatbridge.com)

Description:		browses through the projects via
			the cat_id
			
Create Date:		10/11/00 

Modified Date(s):	
			11/30/2000
			Chris Ryan <chris@greatbridge.com>
				modified project query to only include those
				projects for this site
**************************************************/

$web_page = "browsepage";
include("site_info.php");
$group_group_id = "browse";

$cat_id = (!empty($QUERY_STRING) ? $QUERY_STRING : 0);

# get the name of the category being browsed

$cn_query = "SELECT CAT_NAME, PARENT_ID FROM CATEGORY WHERE CAT_ID = $cat_id";
$cn_result = pg_exec($conn,$cn_query);

if (pg_numrows($cn_result) > 0) {
$curr_cat = pg_fetch_object($cn_result,0);
$parent_id		= $curr_cat->parent_id;
$cat_name 	= $curr_cat->cat_name;
}

# assign the link back variable
if ($parent_id == 0 && !empty($QUERY_STRING)) $back_link = "(All Categories)";
else if ($parent_id > 0 && !empty($QUERY_STRING)) $back_link = "(Back One Level)";


# call the function to build the list of children
$cat_list = getCats($cat_id);


# now get the projects that are in this category or below it
$ps_query = "select distinct a.project_id, b.project_name, b.project_title, " .
	    "b.description from project_category a, project b " .
	    "where a.cat_id in (select c.cat_id from category c " .
	    "where c.type_id = 7 and (c.parent_id = $cat_id or c.cat_id = $cat_id)) " .
	    "and a.project_id = b.project_id " .
	    "and b.approved = 't'" .
            "and b.site_group_id = $site_group_id ";

$ps_result = pg_exec($conn,$ps_query);

$ps = 0;
	while ($row = @pg_fetch_array($ps_result,$ps++)) {
		$project_list[] = array( "project_id" => $row["project_id"],
	                       "project_title" => $row["project_title"],
				 "project_name" => $row["project_name"],
				 "description" => $row["description"]);
	}

include($page_template);

?>
